from __future__ import annotations

import os
import os.path
from glob import glob

import pkg_resources
from tutor import hooks
from tutormfe.hooks import MFE_APPS

from .__about__ import __version__

########################################
# CONFIGURATION
########################################

hooks.Filters.CONFIG_DEFAULTS.add_items(
    [
        # Add your new settings that have default values here.
        # Each new setting is a pair: (setting_name, default_value).
        # Prefix your setting names with 'MOGC_PARTNERSHIPS_'.
        ("MOGC_PARTNERSHIPS_VERSION", __version__),
        ("MOGC_PARTNERSHIPS_REQUIREMENT_SPECIFIER", "mogc-partnerships==0.3.0"),
        ("MOGC_PARTNERSHIPS_INDEX_URL", "https://packages.ai.umich.edu"),
    ]
)

@MFE_APPS.add()
def _add_my_mfe(mfes):
    mfes["partners"] = {
        "repository": "https://github.com/academic-innovation/frontend-app-mogc-partners",
        "port": 1998,
        "version": "master"
    }
    return mfes


########################################
# PATCH LOADING
# (It is safe & recommended to leave
#  this section as-is :)
########################################

# For each file in tutor_mogc_partnerships/patches,
# apply a patch based on the file's name and contents.
for path in glob(
    os.path.join(
        pkg_resources.resource_filename("tutor_mogc_partnerships", "patches"),
        "*",
    )
):
    with open(path, encoding="utf-8") as patch_file:
        hooks.Filters.ENV_PATCHES.add_item((os.path.basename(path), patch_file.read()))
